import {Injectable} from '@angular/core';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {HttpErrorService} from 'src/app/ErrorComponents/http-error.service';
import {Observable} from 'rxjs';
import {catchError} from 'rxjs/operators';
import {MinutePaperWrapperDao} from 'src/app/dao/minute-paper-wrapper.dao';
import {environment} from '../../environments/environment';

const httpOptions = {
  headers: new HttpHeaders({
    'Content-Type':  'application/json'
  })
};

@Injectable()
export class LecturerInfoService {

  constructor(private http$: HttpClient, private errorService: HttpErrorService) {
  }

  public getLecturerClasses(username: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getLecturerClasses', {username: username}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getClassPapers(username: String, classCode: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getClassPapers', {username: username, classCode: classCode}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getPaperQuestions(paperId: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getPaperQuestions', {paperId: paperId}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getPaperAnswers(paperId: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getPaperAnswers', {paperId: paperId}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getTemplates(username: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getTemplates', {username: username}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public createPaper(request: MinutePaperWrapperDao) {
    return this.http$.post(environment.apiUrl + '/createPaper', request, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public deletePaper(paperId: String) {
    return this.http$.post(environment.apiUrl + '/deletePaper', {paperId: paperId}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public createTemplate(request: MinutePaperWrapperDao) {
    return this.http$.post(environment.apiUrl + '/createTemplate', request, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public deleteTemplate(paperId: String) {
    return this.http$.post(environment.apiUrl + '/deleteTemplate', {paperId: paperId}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getClassResponseData(username: String) {
    return this.http$.post(environment.apiUrl + '/getResponseData', {username: username}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getPaperBreakdown(username: String) {
    return this.http$.post(environment.apiUrl + '/getPaperBreakdown', {username: username}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getStudentResponseData(classCode: String) {
    return this.http$.post(environment.apiUrl + '/getStudentResponseData', {classCode: classCode}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getSentimentCloud(paperId: String) {
    return this.http$.post(environment.apiUrl + '/getSentimentCloud', {paperId: paperId}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

}
